@@ -1,5 +1,5 @@
 package Data::Walk::Print;
-use version; our $VERSION = qv('0.020.001');
+use version; our $VERSION = qv('0.020.002');
 
 use Moose::Role;
 requires 
@@ -521,8 +521,8 @@ Data::Walk::Print - A data printing function
 This L<Moose::Role|https://metacpan.org/module/Moose::Manual::Roles> is mostly written 
 as a demonstration module for 
 L<Data::Walk::Extracted|https://metacpan.org/module/Data::Walk::Extracted>.  
-Both L<Data::Dumper|https://metacpan.org/module/Data::Dumper#Functions> - Dumper and 
-L<YAML|https://metacpan.org/module/YAML::Any#SUBROUTINES> - Dump functions are more mature than 
+Both L<Data::Dumper|https://metacpan.org/module/Data::Dumper.pmE<35>Functions> - Dumper and 
+L<YAML|https://metacpan.org/module/YAML::Any.pmE<35>SUBROUTINES> - Dump functions are more mature than 
 the printing function included here.
 
 =head2 USE
@@ -571,7 +571,7 @@ B<Range> This is a Boolean data type and generally accepts 1 or 0
 =back
 
 =head2 Attributes in 
-L<Data::Walk::Extracted|https://metacpan.org/module/Data::Walk::Extracted.pm#Attributes>
+L<Data::Walk::Extracted|https://metacpan.org/module/Data::Walk::Extracted.pmE<35>Attributes>
  - also affect the output.
 
 =head1 Methods
